==> open-xchange-templating_6.14.0.0.orig.tar.gz: open-xchange-templating-6.14.0.0/src/com/openexchange/templating/osgi/Activator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */


package com.openexchange.templating.osgi;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import com.openexchange.config.ConfigurationService;
import com.openexchange.exceptions.osgi.ComponentRegistration;
import com.openexchange.groupware.infostore.InfostoreFacade;
import com.openexchange.server.osgiservice.ServiceDependentRegistration;
import com.openexchange.server.osgiservice.Whiteboard;
import com.openexchange.templating.TemplateErrorMessage;
import com.openexchange.templating.TemplateService;
import com.openexchange.templating.TemplateServiceImpl;
import com.openexchange.templating.impl.OXIntegration;

/**
 * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
 */
public class Activator implements BundleActivator {

    private ComponentRegistration componentRegistration;
    private Whiteboard whiteboard;
    private ServiceDependentRegistration<TemplateServiceImpl> serviceRegistration;

    
    public void start(BundleContext context) throws Exception {
        whiteboard = new Whiteboard(context);
        
        
        this.serviceRegistration = new ServiceDependentRegistration<TemplateServiceImpl>(context, TemplateService.class.getName(), null, whiteboard) {
            private ConfigurationService config;

            @Override
            public TemplateServiceImpl configure(TemplateServiceImpl service) {
                config = get(ConfigurationService.class);
                OXIntegration integration = new OXIntegration(get(InfostoreFacade.class));
                TemplateServiceImpl templates = new TemplateServiceImpl(config);
                templates.setOXFolderHelper(integration);
                templates.setInfostoreHelper(integration);
                return templates;
            }
            
            @Override
            public boolean validateServices() {
                boolean hasProperty = config.getProperty(TemplateServiceImpl.PATH_PROPERTY) != null;
                if(!hasProperty) {
                    LOG.warn(TemplateServiceImpl.PATH_PROPERTY+" is not set. Templating will remain inactive.");
                }
                return hasProperty;
            }
        };
        
        serviceRegistration.start();
        componentRegistration = new ComponentRegistration(context, "TMPL", "com.openexchange.templating", TemplateErrorMessage.EXCEPTIONS);
    }

    public void stop(BundleContext context) throws Exception {
        componentRegistration.unregister();
        serviceRegistration.close();
        whiteboard.close();
    }

}

==> open-xchange-templating_6.16.1.0.orig.tar.gz: open-xchange-templating-6.16.1.0/src/com/openexchange/templating/osgi/Activator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */


package com.openexchange.templating.osgi;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import com.openexchange.config.ConfigurationService;
import com.openexchange.exceptions.osgi.ComponentRegistration;
import com.openexchange.groupware.infostore.InfostoreFacade;
import com.openexchange.server.osgiservice.ServiceDependentRegistration;
import com.openexchange.server.osgiservice.Whiteboard;
import com.openexchange.templating.TemplateErrorMessage;
import com.openexchange.templating.TemplateService;
import com.openexchange.templating.TemplateServiceImpl;
import com.openexchange.templating.impl.OXIntegration;

/**
 * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
 */
public class Activator implements BundleActivator {

    private ComponentRegistration componentRegistration;
    private Whiteboard whiteboard;
    private ServiceDependentRegistration<TemplateServiceImpl> serviceRegistration;

    
    public void start(BundleContext context) throws Exception {
        whiteboard = new Whiteboard(context);
        
        
        this.serviceRegistration = new ServiceDependentRegistration<TemplateServiceImpl>(context, TemplateService.class.getName(), whiteboard) {
            private ConfigurationService config;

            @Override
            public TemplateServiceImpl configure(TemplateServiceImpl service) {
                config = get(ConfigurationService.class);
                OXIntegration integration = new OXIntegration(get(InfostoreFacade.class));
                TemplateServiceImpl templates = new TemplateServiceImpl(config);
                templates.setOXFolderHelper(integration);
                templates.setInfostoreHelper(integration);
                return templates;
            }
            
            @Override
            public boolean validateServices() {
                boolean hasProperty = config.getProperty(TemplateServiceImpl.PATH_PROPERTY) != null;
                if(!hasProperty) {
                    LOG.warn(TemplateServiceImpl.PATH_PROPERTY+" is not set. Templating will remain inactive.");
                }
                return hasProperty;
            }
        };
        
        serviceRegistration.start();
        componentRegistration = new ComponentRegistration(context, "TMPL", "com.openexchange.templating", TemplateErrorMessage.EXCEPTIONS);
    }

    public void stop(BundleContext context) throws Exception {
        componentRegistration.unregister();
        serviceRegistration.close();
        whiteboard.close();
    }

}
